===================
Peek Diagram Plugin
===================

This Peek Plugin provides a generic diagram suitable for mobile or desktop browser use.

The diagram has APIs on the Peek Server service that allows other plugins to load
the graphical data in the diagram. From there the Peek Diagram provides the magic.

The diagram supports the following features :

* Fast model updates (Realtime)

* Online or Fully offline

* Multiple import sources into one canvas.

* Layers, and Levels

* Configurable Z grids for fast overviews.

* Edit support

.. image:: diagram_layers.jpg

